@@ -153,9 +153,9 @@ void BreakpointModel::markContextMenuRequested(Document* document, Mark mark, co
     }
 
     QMenu menu;
-    QAction deleteAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("&Delete Breakpoint"), 0);
-    QAction disableAction(QIcon::fromTheme(QStringLiteral("dialog-cancel")), i18n("&Disable Breakpoint"), 0);
-    QAction enableAction(QIcon::fromTheme(QStringLiteral("dialog-ok-apply")), i18n("&Enable Breakpoint"), 0);
+    QAction deleteAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("&Delete Breakpoint"), nullptr);
+    QAction disableAction(QIcon::fromTheme(QStringLiteral("dialog-cancel")), i18n("&Disable Breakpoint"), nullptr);
+    QAction enableAction(QIcon::fromTheme(QStringLiteral("dialog-ok-apply")), i18n("&Enable Breakpoint"), nullptr);
     menu.addAction(&deleteAction);
     if (b->enabled()) {
         menu.addAction(&disableAction);
@@ -209,7 +209,7 @@ Qt::ItemFlags BreakpointModel::flags(const QModelIndex &index) const
 {
     /* FIXME: all this logic must be in item */
     if (!index.isValid())
-        return 0;
+        return nullptr;
 
     if (index.column() == 0)
         return static_cast<Qt::ItemFlags>(
@@ -245,7 +245,7 @@ bool KDevelop::BreakpointModel::removeRows(int row, int count, const QModelIndex
         if (controller)
             controller->breakpointAboutToBeDeleted(row);
         m_breakpoints.removeAt(row);
-        b->m_model = 0;
+        b->m_model = nullptr;
         // To be changed: the controller is currently still responsible for deleting the breakpoint
         // object
     }
@@ -366,25 +366,25 @@ void BreakpointModel::markChanged(
 
 const QPixmap* BreakpointModel::breakpointPixmap()
 {
-  static QPixmap pixmap=QIcon::fromTheme(QStringLiteral("script-error")).pixmap(QSize(22,22), QIcon::Active, QIcon::Off);
+  static QPixmap pixmap=QIcon::fromTheme(QStringLiteral("breakpoint")).pixmap(QSize(16,16), QIcon::Active, QIcon::Off);
   return &pixmap;
 }
 
 const QPixmap* BreakpointModel::pendingBreakpointPixmap()
 {
-  static QPixmap pixmap=QIcon::fromTheme(QStringLiteral("script-error")).pixmap(QSize(22,22), QIcon::Normal, QIcon::Off);
+  static QPixmap pixmap=QIcon::fromTheme(QStringLiteral("breakpoint")).pixmap(QSize(16,16), QIcon::Normal, QIcon::Off);
   return &pixmap;
 }
 
 const QPixmap* BreakpointModel::reachedBreakpointPixmap()
 {
-  static QPixmap pixmap=QIcon::fromTheme(QStringLiteral("script-error")).pixmap(QSize(22,22), QIcon::Selected, QIcon::Off);
+  static QPixmap pixmap=QIcon::fromTheme(QStringLiteral("breakpoint")).pixmap(QSize(16,16), QIcon::Selected, QIcon::Off);
   return &pixmap;
 }
 
 const QPixmap* BreakpointModel::disabledBreakpointPixmap()
 {
-  static QPixmap pixmap=QIcon::fromTheme(QStringLiteral("script-error")).pixmap(QSize(22,22), QIcon::Disabled, QIcon::Off);
+  static QPixmap pixmap=QIcon::fromTheme(QStringLiteral("breakpoint")).pixmap(QSize(16,16), QIcon::Disabled, QIcon::Off);
   return &pixmap;
 }
 
@@ -444,16 +444,17 @@ void KDevelop::BreakpointModel::updateMarks()
         uint type = breakpointType(breakpoint);
         IF_DEBUG( qCDebug(DEBUGGER) << type << breakpoint->url() << mark->mark(breakpoint->line()); )
 
-        doc->textDocument()->blockSignals(true);
-        if (mark->mark(breakpoint->line()) & AllBreakpointMarks) {
-            if (!(mark->mark(breakpoint->line()) & type)) {
-                mark->removeMark(breakpoint->line(), AllBreakpointMarks);
+        {
+            QSignalBlocker blocker(doc->textDocument());
+            if (mark->mark(breakpoint->line()) & AllBreakpointMarks) {
+                if (!(mark->mark(breakpoint->line()) & type)) {
+                    mark->removeMark(breakpoint->line(), AllBreakpointMarks);
+                    mark->addMark(breakpoint->line(), type);
+                }
+            } else {
                 mark->addMark(breakpoint->line(), type);
             }
-        } else {
-            mark->addMark(breakpoint->line(), type);
         }
-        doc->textDocument()->blockSignals(false);
     }
 
     //remove marks
@@ -461,20 +462,21 @@ void KDevelop::BreakpointModel::updateMarks()
         KTextEditor::MarkInterface *mark = qobject_cast<KTextEditor::MarkInterface*>(doc->textDocument());
         if (!mark) continue;
 
-        doc->textDocument()->blockSignals(true);
-        foreach (KTextEditor::Mark *m, mark->marks()) {
-            if (!(m->type & AllBreakpointMarks)) continue;
-            IF_DEBUG( qCDebug(DEBUGGER) << m->line << m->type; )
-            foreach (Breakpoint *breakpoint, m_breakpoints) {
-                if (breakpoint->kind() != Breakpoint::CodeBreakpoint) continue;
-                if (doc->url() == breakpoint->url() && m->line == breakpoint->line()) {
-                    goto continueNextMark;
+        {
+            QSignalBlocker blocker(doc->textDocument());
+            foreach (KTextEditor::Mark *m, mark->marks()) {
+                if (!(m->type & AllBreakpointMarks)) continue;
+                IF_DEBUG( qCDebug(DEBUGGER) << m->line << m->type; )
+                foreach (Breakpoint *breakpoint, m_breakpoints) {
+                    if (breakpoint->kind() != Breakpoint::CodeBreakpoint) continue;
+                    if (doc->url() == breakpoint->url() && m->line == breakpoint->line()) {
+                        goto continueNextMark;
+                    }
                 }
+                mark->removeMark(m->line, AllBreakpointMarks);
+                continueNextMark:;
             }
-            mark->removeMark(m->line, AllBreakpointMarks);
-            continueNextMark:;
         }
-        doc->textDocument()->blockSignals(false);
     }
 }
 
@@ -495,7 +497,7 @@ void BreakpointModel::aboutToDeleteMovingInterfaceContent(KTextEditor::Document*
 {
     foreach (Breakpoint *breakpoint, m_breakpoints) {
         if (breakpoint->movingCursor() && breakpoint->movingCursor()->document() == document) {
-            breakpoint->setMovingCursor(0);
+            breakpoint->setMovingCursor(nullptr);
         }
     }
 }
@@ -547,7 +549,7 @@ QList<Breakpoint*> KDevelop::BreakpointModel::breakpoints() const
 
 Breakpoint* BreakpointModel::breakpoint(int row)
 {
-    if (row >= m_breakpoints.count()) return 0;
+    if (row >= m_breakpoints.count()) return nullptr;
     return m_breakpoints.at(row);
 }
 
@@ -636,5 +638,5 @@ Breakpoint* BreakpointModel::breakpoint(const QUrl& url, int line) {
             return b;
         }
     }
-    return 0;
+    return nullptr;
 }
