@@ -138,7 +138,7 @@ VariableToolTip::VariableToolTip(QWidget* parent, QPoint position,
 
     QHBoxLayout* buttonBox = new QHBoxLayout();
     buttonBox->setContentsMargins(11, 0, 11, 6);
-    QPushButton* watchThisButton = new QPushButton(i18n("Watch this"));
+    QPushButton* watchThisButton = new QPushButton(i18n("Watch This"));
     buttonBox->addWidget(watchThisButton);
     QPushButton* stopOnChangeButton = new QPushButton(i18n("Stop on Change"));
     buttonBox->addWidget(stopOnChangeButton);
