@@ -17,8 +17,8 @@
   Boston, MA 02110-1301, USA.
 */
 
-#ifndef KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEW_PART_H
-#define KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEW_PART_H
+#ifndef KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEWPLUGIN_H
+#define KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEWPLUGIN_H
 
 #include <interfaces/iplugin.h>
 #include <interfaces/idocumentcontroller.h>
