@@ -10,8 +10,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef GREPVIEWPART_H_
-#define GREPVIEWPART_H_
+#ifndef KDEVPLATFORM_PLUGIN_GREPVIEWPLUGIN_H
+#define KDEVPLATFORM_PLUGIN_GREPVIEWPLUGIN_H
 
 #include <interfaces/iplugin.h>
 #include <interfaces/contextmenuextension.h>
@@ -27,6 +27,7 @@ class GrepOutputViewFactory;
 class GrepViewPlugin : public KDevelop::IPlugin
 {
     Q_OBJECT
+    Q_CLASSINFO( "D-Bus Interface", "org.kdevelop.GrepViewPlugin" )
 
 public:
     explicit GrepViewPlugin( QObject *parent, const QVariantList & = QVariantList() );
