@@ -22,8 +22,9 @@
 #include <QModelIndex>
 
 class KRecursiveFilterProxyModel;
+
+class QAction;
 class QTreeView;
-class QPushButton;
 class QLineEdit;
 class OutlineModel;
 class OutlineViewPlugin;
@@ -42,7 +43,7 @@ private:
     QTreeView* m_tree;
     KRecursiveFilterProxyModel* m_proxy;
     QLineEdit* m_filter;
-    QPushButton* m_sortAlphabetically;
+    QAction* m_sortAlphabeticallyAction;
 
     Q_DISABLE_COPY(OutlineWidget)
 public slots:
