@@ -149,7 +149,7 @@ LocalPatchSource* PatchReviewToolView::GetLocalPatchSource() {
     IPatchSource::Ptr ips = m_plugin->patch();
 
     if ( !ips )
-        return 0;
+        return nullptr;
     return dynamic_cast<LocalPatchSource*>( ips.data() );
 }
 
@@ -176,7 +176,7 @@ void PatchReviewToolView::fillEditFromPatch() {
     }
 
     bool showTests = false;
-    IProject* project = 0;
+    IProject* project = nullptr;
     QMap<QUrl, VcsStatusInfo::State> files = ipatch->additionalSelectableFiles();
     QMap<QUrl, VcsStatusInfo::State>::const_iterator it = files.constBegin();
 
@@ -227,7 +227,7 @@ void PatchReviewToolView::showEditDialog() {
     m_exportMenu = new Purpose::Menu(this);
     connect(m_exportMenu, &Purpose::Menu::finished, this, [](const QJsonObject &output, int error, const QString &message) {
         if (error==0) {
-            KMessageBox::information(0, i18n("<qt>You can find the new request at:<br /><a href='%1'>%1</a> </qt>", output["url"].toString()),
+            KMessageBox::information(nullptr, i18n("<qt>You can find the new request at:<br /><a href='%1'>%1</a> </qt>", output["url"].toString()),
                                     QString(), QString(), KMessageBox::AllowLink);
         } else {
             QMessageBox::warning(nullptr, i18n("Error exporting"), i18n("Couldn't export the patch.\n%1", message));
@@ -354,13 +354,13 @@ void PatchReviewToolView::seekFile(bool forwards)
 
     if(newUrl.isValid())
     {
-        activate( newUrl, forwards ? current : 0 );
+        open( newUrl, true );
     }else{
         qCDebug(PLUGIN_PATCHREVIEW) << "found no valid target url";
     }
 }
 
-void PatchReviewToolView::activate( const QUrl& url, IDocument* buddy ) const
+void PatchReviewToolView::open( const QUrl& url, bool activate ) const
 {
     qCDebug(PLUGIN_PATCHREVIEW) << "activating url" << url;
     // If the document is already open in this area, just re-activate it
@@ -369,17 +369,44 @@ void PatchReviewToolView::activate( const QUrl& url, IDocument* buddy ) const
         {
             if(view->document() == dynamic_cast<Sublime::Document*>(doc))
             {
-                ICore::self()->documentController()->activateDocument(doc);
+                if (activate) {
+                    // use openDocument() for the activation so that the document is added to File/Open Recent.
+                    ICore::self()->documentController()->openDocument(doc->url(), KTextEditor::Range::invalid());
+                }
                 return;
             }
         }
     }
 
-    // If the document is not open yet, open it in the correct order
-    IDocument* newDoc = ICore::self()->documentController()->openDocument(url, KTextEditor::Range(), IDocumentController::DefaultMode, QString(), buddy);
-    KTextEditor::View* view = 0;
+    QStandardItem* item = m_fileModel->itemForUrl( url );
+
+    IDocument* buddyDoc = nullptr;
+
+    if (m_plugin->patch() && item) {
+        for (int preRow = item->row() - 1; preRow >= 0; --preRow) {
+            QStandardItem* preItem = m_fileModel->item(preRow);
+            if (!m_fileModel->isCheckable() || preItem->checkState() == Qt::Checked) {
+                // found valid predecessor, take it as buddy
+                buddyDoc = ICore::self()->documentController()->documentForUrl(preItem->index().data(VcsFileChangesModel::UrlRole).toUrl());
+                if (buddyDoc) {
+                    break;
+                }
+            }
+        }
+        if (!buddyDoc) {
+            buddyDoc = ICore::self()->documentController()->documentForUrl(m_plugin->patch()->file());
+        }
+    }
+
+    // we simplify and assume that documents to be opened without activating them also need not be
+    // added to the Files/Open Recent menu.
+    IDocument* newDoc = ICore::self()->documentController()->openDocument(url, KTextEditor::Range::invalid(),
+        activate ? IDocumentController::DefaultMode : IDocumentController::DoNotActivate|IDocumentController::DoNotAddToRecentOpen,
+        QString(), buddyDoc);
+
+    KTextEditor::View* view = nullptr;
     if(newDoc)
-        view= newDoc->activeTextView();
+        view = newDoc->activeTextView();
 
     if(view && view->cursorPosition().line() == 0)
         m_plugin->seekHunk( true, url );
@@ -387,7 +414,7 @@ void PatchReviewToolView::activate( const QUrl& url, IDocument* buddy ) const
 
 void PatchReviewToolView::fileItemChanged( QStandardItem* item )
 {
-    if (item->column()!=0)
+    if (item->column() != 0 || !m_plugin->patch())
         return;
 
     QUrl url = item->index().data(VcsFileChangesModel::UrlRole).toUrl();
@@ -396,8 +423,7 @@ void PatchReviewToolView::fileItemChanged( QStandardItem* item )
 
     KDevelop::IDocument* doc = ICore::self()->documentController()->documentForUrl(url);
     if(m_fileModel->isCheckable() && item->checkState() != Qt::Checked)
-    {
-        // Eventually close the document
+    {   // The file was deselected, so eventually close it
         if(doc && doc->state() == IDocument::Clean)
         {
             foreach(Sublime::View* view, ICore::self()->uiController()->activeArea()->views())
@@ -410,7 +436,8 @@ void PatchReviewToolView::fileItemChanged( QStandardItem* item )
             }
         }
     } else if (!doc) {
-        ICore::self()->documentController()->openDocument(url, KTextEditor::Range::invalid(), IDocumentController::DoNotActivate);
+        // Maybe the file was unchecked before, or it  was just loaded.
+        open( url, false );
     }
 }
 
@@ -443,7 +470,7 @@ void PatchReviewToolView::finishReview() {
 void PatchReviewToolView::fileDoubleClicked( const QModelIndex& idx )
 {
     const QUrl file = idx.data(VcsFileChangesModel::UrlRole).toUrl();
-    activate( file );
+    open( file, true );
 }
 
 void PatchReviewToolView::kompareModelChanged() {
@@ -479,7 +506,7 @@ void PatchReviewToolView::kompareModelChanged() {
         }
     }
 
-    for( QMap<QUrl, KDevelop::VcsStatusInfo::State>::const_iterator it = additionalUrls.constBegin(); it != additionalUrls.constEnd(); it++ ) {
+    for( QMap<QUrl, KDevelop::VcsStatusInfo::State>::const_iterator it = additionalUrls.constBegin(); it != additionalUrls.constEnd(); ++it ) {
         VcsStatusInfo status;
         status.setUrl( it.key() );
         status.setState( it.value() );
@@ -517,7 +544,7 @@ void PatchReviewToolView::runTests()
         return;
     }
 
-    IProject* project = 0;
+    IProject* project = nullptr;
     QMap<QUrl, VcsStatusInfo::State> files = ipatch->additionalSelectableFiles();
     QMap<QUrl, VcsStatusInfo::State>::const_iterator it = files.constBegin();
 
