@@ -18,8 +18,8 @@
  * Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
-#ifndef KDEVPLATFORM_PLUGIN_SWITCHTOBUDDY_H
-#define KDEVPLATFORM_PLUGIN_SWITCHTOBUDDY_H
+#ifndef KDEVPLATFORM_PLUGIN_SWITCHTOBUDDYPLUGIN_H
+#define KDEVPLATFORM_PLUGIN_SWITCHTOBUDDYPLUGIN_H
 
 #include <interfaces/iplugin.h>
 #include <interfaces/contextmenuextension.h>
@@ -83,4 +83,4 @@ private:
 };
 
 
-#endif // KDEVPLATFORM_PLUGIN_SWITCHTOBUDDY_H
+#endif // KDEVPLATFORM_PLUGIN_SWITCHTOBUDDYPLUGIN_H
