@@ -20,35 +20,23 @@
 #define WELCOMEPAGEVIEW_H
 
 #include <QQuickWidget>
-#include <sublime/view.h>
 
-namespace Sublime
-{
+namespace Sublime {
 class Area;
 }
 
-namespace KDevelop { class IProject; }
-
-class WelcomePageView : public Sublime::View
-{
-    Q_OBJECT
-    public:
-        explicit WelcomePageView(Sublime::Document* doc, WidgetOwnership ws = DoNotTakeOwnerShip);
-
-        QWidget* createWidget(QWidget* parent) override;
-};
-
+namespace KDevelop {
+class IProject;
+}
 
 class WelcomePageWidget : public QQuickWidget
 {
     Q_OBJECT
 public:
-    explicit WelcomePageWidget(const QList< KDevelop::IProject* >& projects, QWidget* parent = 0);
+    explicit WelcomePageWidget(const QList< KDevelop::IProject* >& projects, QWidget* parent = nullptr);
 
 public slots:
     void areaChanged(Sublime::Area* a);
 };
 
-void trySetupWelcomePageView();
-
 #endif // WELCOMEPAGEVIEW_H
