@@ -17,6 +17,7 @@
     Boston, MA 02110-1301, USA.
 */
 
+#include "debug.h"
 #include "helper.h"
 #include "path.h"
 
@@ -47,12 +48,14 @@ using namespace KDevelop;
 
 bool KDevelop::removeUrl(const KDevelop::IProject* project, const QUrl& url, const bool isFolder)
 {
+    qCDebug(PROJECT) << "Removing url:" << url << "from project" << project;
+
     QWidget* window = QApplication::activeWindow();
 
     auto job = KIO::stat(url, KIO::StatJob::DestinationSide, 0);
     KJobWidgets::setWindow(job, window);
     if (!job->exec()) {
-        qWarning() << "tried to remove non-existing url:" << url << project << isFolder;
+        qCWarning(PROJECT) << "tried to remove non-existing url:" << url << project << isFolder;
         return true;
     }
 
