@@ -127,7 +127,7 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent)
     QModelIndex widthidx = idx;
     if( model->rowCount( idx ) > 0 )
     {
-        widthidx = idx.child( 0, 0 );
+        widthidx = model->index( 0, 0, idx );
     }
     QModelIndex parentidx = widthidx.parent();
     while( parentidx.isValid() )
@@ -198,7 +198,7 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent)
     connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, static_cast<void(LaunchConfigurationDialog::*)()>(&LaunchConfigurationDialog::saveConfig) );
     mainLayout->addWidget(buttonBox);
 
-    resize( QSize(qMax(700, sizeHint().width()), qMax(500, sizeHint().height())) );
+    resize( QSize(qMax(1200, sizeHint().width()), qMax(500, sizeHint().height())) );
 }
 
 void LaunchConfigurationDialog::doTreeContextMenu(QPoint point)
@@ -284,7 +284,6 @@ void LaunchConfigurationDialog::selectionChanged(QItemSelection selected, QItemS
         delete w;
     }
 
-    debugger->clear();
     if( !selected.indexes().isEmpty() )
     {
         QModelIndex idx = selected.indexes().first();
@@ -298,23 +297,25 @@ void LaunchConfigurationDialog::selectionChanged(QItemSelection selected, QItemS
             connect( l, &LaunchConfiguration::nameChanged, this, &LaunchConfigurationDialog::updateNameLabel );
             if( lm )
             {
+                QVariant currentLaunchMode = idx.sibling(idx.row(), 1).data(Qt::EditRole);
                 {
                     QSignalBlocker blocker(debugger);
                     QList<ILauncher*> launchers = l->type()->launchers();
+
+                    debugger->clear();
                     for( QList<ILauncher*>::const_iterator it = launchers.constBegin(); it != launchers.constEnd(); ++it )
                     {
                         if( ((*it)->supportedModes().contains( lm->id() ) ) ) {
                             debugger->addItem( (*it)->name(), (*it)->id() );
                         }
                     }
+
+                    debugger->setCurrentIndex(debugger->findData(currentLaunchMode));
                 }
 
                 debugger->setVisible(debugger->count()>0);
                 debugLabel->setVisible(debugger->count()>0);
 
-                QVariant currentLaunchMode = idx.sibling(idx.row(), 1).data(Qt::EditRole);
-                debugger->setCurrentIndex(debugger->findData(currentLaunchMode));
-
                 ILauncher* launcher = l->type()->launcherForId( currentLaunchMode.toString() );
                 if( launcher )
                 {
