@@ -26,7 +26,6 @@
 
 #include "project.h"
 
-#include <QDBusConnection>
 #include <QDebug>
 #include <QSet>
 #include <QTemporaryFile>
@@ -313,7 +312,7 @@ public:
                                 i18n( "Could not load %1, a project with the same name '%2' is already open.",
                                 projectFile.pathOrUrl(), name ) );
 
-            qWarning() << "Trying to open a project with a name that is already used by another open project";
+            qCWarning(SHELL) << "Trying to open a project with a name that is already used by another open project";
             return true;
         }
         return false;
@@ -408,8 +407,6 @@ Project::Project( QObject *parent )
         : IProject( parent )
         , d( new ProjectPrivate )
 {
-    QDBusConnection::sessionBus().registerObject( QStringLiteral("/org/kdevelop/Project"), this, QDBusConnection::ExportScriptableSlots );
-
     d->project = this;
     d->manager = nullptr;
     d->topItem = nullptr;
@@ -522,7 +519,7 @@ void Project::close()
 {
     Q_ASSERT(d->topItem);
     if (d->topItem->row() == -1) {
-        qWarning() << "Something went wrong. ProjectFolderItem detached. Project closed during reload?";
+        qCWarning(SHELL) << "Something went wrong. ProjectFolderItem detached. Project closed during reload?";
         return;
     }
 
