@@ -13,6 +13,13 @@
 
 #include <QWidget>
 
+struct ProjectFileChoice {
+    QString text;
+    QString pluginId;
+    QString iconName;
+    QString fileName;
+};
+
 namespace Ui
 {
     class ProjectInfoPage;
@@ -25,13 +32,13 @@ class ProjectInfoPage : public QWidget
 {
 Q_OBJECT
 public:
-    explicit ProjectInfoPage( QWidget* parent = 0 );
+    explicit ProjectInfoPage( QWidget* parent = nullptr );
     ~ProjectInfoPage() override;
     void setProjectName( const QString& );
-    void setProjectManager( const QString& );
+    void populateProjectFileCombo( const QVector<ProjectFileChoice>& choices );
 signals:
     void projectNameChanged( const QString& );
-    void projectManagerChanged( const QString& );
+    void projectManagerChanged( const QString& pluginId, const QString & fileName);
 private slots:
     void changeProjectManager( int );
 private:
