@@ -267,7 +267,7 @@ bool TextDocument::isTextDocument() const
     {
         /// @todo Somehow it can happen that d->document is zero, which makes
         /// code relying on "isTextDocument() == (bool)textDocument()" crash
-        qWarning() << "Broken text-document: " << url();
+        qCWarning(SHELL) << "Broken text-document: " << url();
         return false;
     }
 
