@@ -57,8 +57,8 @@ public:
     /**@return the controller for this document.*/
     Controller *controller() const;
 
-    /**@return the document title.*/
     enum TitleType { Normal, Extended};
+    /**@return the document title.*/
     virtual QString title(TitleType type = Normal) const;
     /**Set the document title.*/
     void setTitle(const QString& newTitle);
@@ -129,7 +129,7 @@ protected:
     /**Reimplement this to create and return the new widget to display
     this document in the view. This method is used by View class when it
     is asked for its widget.*/
-    virtual QWidget *createViewWidget(QWidget *parent = 0) = 0;
+    virtual QWidget *createViewWidget(QWidget *parent = nullptr) = 0;
     /** Closes all views associated to this document */
     virtual void closeViews();
 
