@@ -49,6 +49,7 @@ VCSCommitDiffPatchSource::VCSCommitDiffPatchSource(VCSDiffUpdater* updater)
     Q_ASSERT(m_vcs);
     m_commitMessageWidget = new QWidget;
     QVBoxLayout* layout = new QVBoxLayout(m_commitMessageWidget.data());
+    layout->setMargin(0);
 
     m_commitMessageEdit = new KTextEdit;
     m_commitMessageEdit.data()->setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont));
@@ -288,7 +289,7 @@ bool showVcsDiff(IPatchSource* vcsDiff)
         patchReview->startReview(vcsDiff);
         return true;
     } else {
-        qWarning() << "Patch review plugin not found";
+        qCWarning(VCS) << "Patch review plugin not found";
         return false;
     }
 }
